==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Borrar as estatísticas', # MODIF

	// I
	'icone_evolution_visites' => 'Evolución das visitas<br />@visites@ visitas',
	'icone_repartition_actuelle' => 'Mostrar a distribución actual',
	'icone_repartition_visites' => 'Distribución das visitas',
	'icone_statistiques_visites' => 'Estatísticas',
	'info_affichier_visites_articles_plus_visites' => 'Mostrar as visitas de <b>os artigos máis visitados dende o principio:</b>',
	'info_comment_lire_tableau' => 'Cómo interpretar este cadro',
	'info_forum_statistiques' => 'Estatísticas das visitas',
	'info_popularite_2' => 'popularidade do web:',
	'info_popularite_3' => 'popularidade: @popularite@; visitas: @visites@',
	'info_popularite_5' => 'popularidade :',
	'info_previsions' => 'previsións:',
	'info_question_vignettes_referer' => 'Cando vostede consulte as estatísticas, pode visualizar resumos dos webs que orixinan as visitas.',
	'info_question_vignettes_referer_oui' => 'Mostrar as capturas de web de orixe das visitas',
	'info_visites' => 'visitas:',
	'info_visites_plus_populaires' => 'Mostrar as visitas para <b>os artigos máis populares</b> e para <b>os últimos artigos publicados:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Xestionar as estatísticas', # MODIF

	// O
	'onglet_origine_visites' => 'Orixe das visitas',
	'onglet_repartition_debut' => 'desde o principio',
	'onglet_repartition_lang' => 'Distribución por linguas',

	// T
	'texte_admin_effacer_stats' => 'Este comando borra todos os datos ligados ás estatísticas de visita do web, e inclúe a popularidade dos artigos.',
	'texte_comment_lire_tableau' => 'O rango do artigo, na clasificación por popularidade, está indicado á marxe; a popularidade do artigo (unha estimación do número de visitas cotiás que terá se o ritmo actual de consulta se mantén) e o número de visitas recibidas dende o principio son amosadas no bolo que aparece cando pasas co rato por riba do título.',
	'texte_signification' => 'As barras escuras representan as entradas acumuladas (total dos apartados), as barras claras o número de visitas para cada tema.',
	'titre_evolution_visite' => 'Evolución das visitas',
	'titre_liens_entrants' => 'As ligazóns entrantes do día',
	'titre_page_statistiques' => 'Estatísticas por temas',
	'titre_page_statistiques_visites' => 'Estatísticas das visitas'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Borrar as estatísticas', # MODIF

	// I
	'icone_evolution_visites' => 'Evolución das visitas<br />@visites@ visitas',
	'icone_repartition_actuelle' => 'Mostrar a distribución actual',
	'icone_repartition_visites' => 'Distribución das visitas',
	'icone_statistiques_visites' => 'Estatísticas',
	'info_affichier_visites_articles_plus_visites' => 'Mostrar as visitas de <b>os artigos máis visitados dende o principio:</b>',
	'info_comment_lire_tableau' => 'Cómo interpretar este cadro',
	'info_forum_statistiques' => 'Estatísticas das visitas',
	'info_popularite_2' => 'popularidade do web:',
	'info_popularite_3' => 'popularidade: @popularite@; visitas: @visites@',
	'info_popularite_5' => 'popularidade :',
	'info_previsions' => 'previsións:',
	'info_question_vignettes_referer' => 'Cando vostede consulte as estatísticas, pode visualizar resumos dos webs que orixinan as visitas.', # MODIF
	'info_question_vignettes_referer_oui' => 'Mostrar as capturas de web de orixe das visitas',
	'info_visites' => 'visitas:',
	'info_visites_plus_populaires' => 'Mostrar as visitas para <b>os artigos máis populares</b> e para <b>os últimos artigos publicados:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Xestionar as estatísticas', # MODIF

	// O
	'onglet_origine_visites' => 'Orixe das visitas',
	'onglet_repartition_debut' => 'desde o principio',
	'onglet_repartition_lang' => 'Distribución por linguas',

	// T
	'texte_admin_effacer_stats' => 'Este comando borra todos os datos ligados ás estatísticas de visita do web, e inclúe a popularidade dos artigos.',
	'texte_comment_lire_tableau' => 'O rango do artigo, na clasificación por popularidade, está indicado á marxe; a popularidade do artigo (unha estimación do número de visitas cotiás que terá se o ritmo actual de consulta se mantén) e o número de visitas recibidas dende o principio son amosadas no bolo que aparece cando pasas co rato por riba do título.',
	'texte_signification' => 'As barras escuras representan as entradas acumuladas (total dos apartados), as barras claras o número de visitas para cada tema.',
	'titre_evolution_visite' => 'Evolución das visitas',
	'titre_liens_entrants' => 'As ligazóns entrantes do día',
	'titre_page_statistiques' => 'Estatísticas por temas',
	'titre_page_statistiques_visites' => 'Estatísticas das visitas'
);
